@@ -13,23 +13,23 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 /**
  * SECTION:element-amrnbdec
- * @title: amrnbdec
  * @see_also: #GstAmrnbEnc, #GstAmrParse
  *
- * AMR narrowband decoder based on the
- * [opencore codec implementation](http://sourceforge.net/projects/opencore-amr).
- *
- * ## Example launch line
+ * AMR narrowband decoder based on the 
+ * <ulink url="http://sourceforge.net/projects/opencore-amr">opencore codec implementation</ulink>.
+ * 
+ * <refsect2>
+ * <title>Example launch line</title>
  * |[
- * gst-launch-1.0 filesrc location=abc.amr ! amrparse ! amrnbdec ! audioconvert ! audioresample ! autoaudiosink
+ * gst-launch filesrc location=abc.amr ! amrparse ! amrnbdec ! audioresample ! audioconvert ! alsasink
  * ]|
- *
+ * </refsect2>
  */
 
 #ifdef HAVE_CONFIG_H
@@ -96,8 +96,8 @@ static void gst_amrnbdec_get_property (GObject * object, guint prop_id,
 static gboolean gst_amrnbdec_start (GstAudioDecoder * dec);
 static gboolean gst_amrnbdec_stop (GstAudioDecoder * dec);
 static gboolean gst_amrnbdec_set_format (GstAudioDecoder * dec, GstCaps * caps);
-static GstFlowReturn gst_amrnbdec_parse (GstAudioDecoder * dec,
-    GstAdapter * adapter, gint * offset, gint * length);
+static gboolean gst_amrnbdec_parse (GstAudioDecoder * dec, GstAdapter * adapter,
+    gint * offset, gint * length);
 static GstFlowReturn gst_amrnbdec_handle_frame (GstAudioDecoder * dec,
     GstBuffer * buffer);
 
@@ -114,13 +114,15 @@ gst_amrnbdec_class_init (GstAmrnbDecClass * klass)
   object_class->set_property = gst_amrnbdec_set_property;
   object_class->get_property = gst_amrnbdec_get_property;
 
-  gst_element_class_add_static_pad_template (element_class, &sink_template);
-  gst_element_class_add_static_pad_template (element_class, &src_template);
+  gst_element_class_add_pad_template (element_class,
+      gst_static_pad_template_get (&sink_template));
+  gst_element_class_add_pad_template (element_class,
+      gst_static_pad_template_get (&src_template));
 
   gst_element_class_set_static_metadata (element_class, "AMR-NB audio decoder",
       "Codec/Decoder/Audio",
       "Adaptive Multi-Rate Narrow-Band audio decoder",
-      "GStreamer maintainers <gstreamer-devel@lists.freedesktop.org>");
+      "GStreamer maintainers <gstreamer-devel@lists.sourceforge.net>");
 
   base_class->start = GST_DEBUG_FUNCPTR (gst_amrnbdec_start);
   base_class->stop = GST_DEBUG_FUNCPTR (gst_amrnbdec_stop);
@@ -136,17 +138,11 @@ gst_amrnbdec_class_init (GstAmrnbDecClass * klass)
 
   GST_DEBUG_CATEGORY_INIT (gst_amrnbdec_debug, "amrnbdec", 0,
       "AMR-NB audio decoder");
-
-  gst_type_mark_as_plugin_api (GST_AMRNB_VARIANT_TYPE, 0);
 }
 
 static void
 gst_amrnbdec_init (GstAmrnbDec * amrnbdec)
 {
-  gst_audio_decoder_set_needs_format (GST_AUDIO_DECODER (amrnbdec), TRUE);
-  gst_audio_decoder_set_use_default_pad_acceptcaps (GST_AUDIO_DECODER_CAST
-      (amrnbdec), TRUE);
-  GST_PAD_SET_ACCEPT_TEMPLATE (GST_AUDIO_DECODER_SINK_PAD (amrnbdec));
 }
 
 static gboolean
@@ -243,12 +239,14 @@ gst_amrnbdec_parse (GstAudioDecoder * dec, GstAdapter * adapter,
   gint block, mode;
 
   size = gst_adapter_available (adapter);
-  if (size < 1)
-    return GST_FLOW_ERROR;
+  g_return_val_if_fail (size > 0, GST_FLOW_ERROR);
 
   gst_audio_decoder_get_parse_state (dec, &sync, &eos);
 
   /* need to peek data to get the size */
+  if (size < 1)
+    return GST_FLOW_ERROR;
+
   gst_adapter_copy (adapter, head, 0, 1);
 
   /* get size */
@@ -291,6 +289,9 @@ gst_amrnbdec_handle_frame (GstAudioDecoder * dec, GstBuffer * buffer)
   if (!buffer || !gst_buffer_get_size (buffer))
     return GST_FLOW_OK;
 
+  if (amrnbdec->rate == 0 || amrnbdec->channels == 0)
+    goto not_negotiated;
+
   gst_buffer_map (buffer, &inmap, GST_MAP_READ);
 
   /* get output */
@@ -304,4 +305,12 @@ gst_amrnbdec_handle_frame (GstAudioDecoder * dec, GstBuffer * buffer)
   gst_buffer_unmap (buffer, &inmap);
 
   return gst_audio_decoder_finish_frame (dec, out, 1);
+
+  /* ERRORS */
+not_negotiated:
+  {
+    GST_ELEMENT_ERROR (amrnbdec, STREAM, TYPE_NOT_FOUND, (NULL),
+        ("Decoder is not initialized"));
+    return GST_FLOW_NOT_NEGOTIATED;
+  }
 }
