@@ -13,27 +13,25 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 /* Element-Checklist-Version: 5 */
 
 /**
  * SECTION:element-rtspreal
- * @title: rtspreal
  *
  * A RealMedia RTSP extension
+ *
+ * Last reviewed on 2007-07-25 (0.10.14)
  */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
-#ifdef HAVE_STDINT_H
-#include <stdint.h>
-#endif
-
 #include <stdlib.h>
+#include "_stdint.h"
 #include <string.h>
 
 #include <gst/rtsp/gstrtspextension.h>
@@ -209,9 +207,9 @@ G_STMT_START {			       \
 #define READ_BUFFER_GEN(src, func, name, dest, dest_len)    \
 G_STMT_START {			                            \
   dest = (gchar *)func (src, name);                         \
-  dest_len = 0;						    \
   if (!dest) {                                              \
     dest = (char *) "";                                     \
+    dest_len = 0;                                           \
   }                                                         \
   else if (!strncmp (dest, "buffer;\"", 8)) {               \
     dest += 8;                                              \
@@ -397,7 +395,7 @@ rtsp_ext_real_parse_sdp (GstRTSPExtension * ext, GstSDPMessage * sdp,
     stream->mime_type = g_strndup (str, stream->mime_type_len);
 
     /* FIXME: Depending on the current bandwidth, we need to select one
-     * bandwidth out of a list offered by the server. Someone needs to write
+     * bandwith out of a list offered by the server. Someone needs to write
      * a parser for strings like
      *
      * #($Bandwidth < 67959),TimestampDelivery=T,DropByN=T,priority=9;
@@ -599,10 +597,6 @@ rtsp_ext_real_parse_sdp (GstRTSPExtension * ext, GstSDPMessage * sdp,
   /* ERRORS */
 strange_opaque_data:
   {
-    g_string_free (rules, TRUE);
-    g_hash_table_destroy (vars);
-    g_free (data);
-
     GST_ELEMENT_ERROR (ctx, RESOURCE, WRITE, ("Strange opaque data."), (NULL));
     return FALSE;
   }
@@ -648,7 +642,6 @@ create_request_failed:
   {
     GST_ELEMENT_ERROR (ctx, LIBRARY, INIT,
         ("Could not create request."), (NULL));
-    g_free (req_url);
     goto reset;
   }
 send_error:
